<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class EDD_Recurring_Gateway {

	public $id;
	public $friendly_name = '';
	public $subscriptions = array();
	public $purchase_data = array();
	public $offsite = false;
	public $email = 0;
	public $customer_id = 0;
	public $user_id = 0;
	public $payment_id = 0;

	/**
	 * Get things started
	 *
	 * @access      public
	 * @since       2.4
	 * @return      void
	 */
	public function __construct() {

		$this->init();

		add_action( 'edd_checkout_error_checks', array( $this, 'checkout_errors' ), 0, 2 );
		add_action( 'edd_gateway_' . $this->id, array( $this, 'process_checkout' ), 0 );
		add_action( 'init', array( $this, 'require_login' ), 9 );
		add_action( 'init', array( $this, 'process_webhooks' ), 9 );
		add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ), 10 );
		add_action( 'edd_cancel_subscription', array( $this, 'process_cancellation' ) );
		add_filter( 'edd_subscription_can_cancel', array( $this, 'can_cancel' ), 10, 2 );
		add_filter( 'edd_subscription_can_update', array( $this, 'can_update' ), 10, 2 );
		add_action( 'edd_recurring_cancel_' . $this->id . '_subscription', array( $this, 'cancel' ), 10, 2 );
		add_action( 'edd_recurring_update_payment_form', array( $this, 'update_payment_method_form' ), 10, 1 );
		add_action( 'edd_recurring_update_subscription_payment_method', array( $this, 'process_payment_method_update' ), 10, 3 );
		add_action( 'edd_recurring_update_' . $this->id . '_subscription', array( $this, 'update_payment_method' ), 10, 2 );
		add_action( 'edd_after_cc_fields', array( $this, 'after_cc_fields' ) );

		add_filter( 'edd_subscription_profile_link_' . $this->id, array( $this, 'link_profile_id' ), 10, 2 );
	}

	/**
	 * Setup gateway ID and possibly load API libraries
	 *
	 * @access      public
	 * @since       2.4
	 * @return      void
	 */
	public function init() {

		$this->id = '';

	}

	/**
	 * Enqueue necessary scripts. Perhaps only enqueue when edd_is_checkout()
	 *
	 * @access      public
	 * @since       2.4
	 * @return      void
	 */
	public function scripts() {
	}

	/**
	 * Validate checkout fields
	 *
	 * @access      public
	 * @since       2.4
	 * @return      void
	 */
	public function validate_fields( $data, $posted ) {

		/*

		if( true ) {
			edd_set_error( 'error_id_here', __( 'Error message here', 'edd-recurring' ) );
		}

		*/

	}

	/**
	 * Creates subscription payment profiles and sets the IDs so they can be stored
	 *
	 * @access      public
	 * @since       2.4
	 * @return      void
	 */
	public function create_payment_profiles() {

		// Gateways loop through each download and creates a payment profile and then sets the profile ID

		foreach ( $this->subscriptions as $key => $subscription ) {
			$this->subscriptions[ $key ]['profile_id'] = '1234';
		}

	}

	/**
	 * Finishes the signup process by redirecting to the success page or to an off-site payment page
	 *
	 * @access      public
	 * @since       2.4
	 * @return      void
	 */
	public function complete_signup() {

		wp_redirect( edd_get_success_page_uri() );
		exit;
	}

	/**
	 * Processes webhooks from the payment processor
	 *
	 * @access      public
	 * @since       2.4
	 * @return      void
	 */
	public function process_webhooks() {

		// set webhook URL to: home_url( 'index.php?edd-listener=' . $this->id );

		if ( empty( $_GET['edd-listener'] ) || $this->id !== $_GET['edd-listener'] ) {
			return;
		}

		// process webhooks here

	}

	/**
	 * Determines if a subscription can be cancelled through the gateway
	 *
	 * @access      public
	 * @since       2.4
	 * @return      bool
	 */
	public function can_cancel( $ret, $subscription ) {
		return $ret;
	}

	/**
	 * Cancels a subscription
	 *
	 * @access      public
	 * @since       2.4
	 * @return      bool
	 */
	public function cancel( $subscription, $valid ) { }

	/**
	 * Determines if a subscription can be cancelled through a gateway
	 *
	 * @since  2.4
	 * @param  bool   $ret            Default stting (false)
	 * @param  object $subscription   The subscription
	 * @return bool
	 */
	public function can_update( $ret, $subscription ) {
		return $ret;
	}

	/**
	 * Process the update payment form
	 *
	 * @since  2.4
	 * @param  int  $subscriber    EDD_Recurring_Subscriber
	 * @param  int  $subscription  EDD_Subscription
	 * @return void
	 */
	public function update_payment_method( $subscriber, $subscription ) { }

	/**
	 * Outputs the payment method update form
	 *
	 * @since  2.4
	 * @param  object $subscription The subscription object
	 * @return void
	 */
	public function update_payment_method_form( $subscription ) {

		if ( $subscription->gateway !== $this->id ) {
			return;
		}

		ob_start();
		edd_get_cc_form();
		echo ob_get_clean();

	}

	/**
	 * Outputs any information after the Credit Card Fields
	 *
	 * @since  2.4
	 * @return void
	 */
	public function after_cc_fields() {}


	/****************************************************************
	 * Below methods should not be extended except in rare cases
	 ***************************************************************/


	/**
	 * Processes the checkout screen and sends sets up the subscription data for hand-off to the gateway
	 *
	 * @access      public
	 * @since       2.4
	 * @return      void
	 */
	public function process_checkout( $purchase_data ) {

		if ( ! edd_recurring()->is_purchase_recurring( $purchase_data ) ) {
			return; // Not a recurring purchase so bail
		}

		if ( ! wp_verify_nonce( $purchase_data['gateway_nonce'], 'edd-gateway' ) ) {
			wp_die( __( 'Nonce verification has failed', 'edd' ), __( 'Error', 'edd-recurring' ), array( 'response' => 403 ) );
		}

		if ( $purchase_data['user_info']['id'] < 1 && ! class_exists( 'EDD_Auto_Register' ) ) {
			edd_set_error( 'edd_recurring_logged_in', __( 'You must log in or create an account to purchase a subscription', 'edd-recurring' ) );
		}

		// Initial validation
		do_action( 'edd_recurring_process_checkout', $purchase_data, $this );

		$errors = edd_get_errors();

		if ( $errors ) {

			edd_send_back_to_checkout( '?payment-mode=' . $this->id );

		}

		$this->purchase_data = $purchase_data;
		$this->user_id       = $purchase_data['user_info']['id'];
		$this->email         = $purchase_data['user_info']['email'];

		$subscriber = new EDD_customer( $this->email );
		if ( empty( $subscriber->id ) ) {

			$name = '';
			if ( ! empty( $purchase_data['user_info']['first_name'] ) && ! empty( $purchase_data['user_info']['last_name'] ) ) {
				$name = $purchase_data['user_info']['first_name'] . ' ' . $purchase_data['user_info']['last_name'];
			}

			$subscriber_data = array(
				'name'        => $name,
				'email'       => $purchase_data['user_info']['email'],
				'user_id'     => $this->user_id,
			);

			$subscriber->create( $subscriber_data );

		}

		$this->customer_id = $subscriber->id;

		foreach ( $this->purchase_data['cart_details'] as $key => $item ) {

			if ( ! isset( $item['item_number']['options'] ) || ! isset( $item['item_number']['options']['recurring'] ) ) {
				continue;
			}

			if( edd_get_option( 'recurring_one_time_discounts' ) ) {
				$recurring_amount = $item['subtotal'] + $item['tax'];
			} else {
				$recurring_amount = $item['price'];
			}

			$fees = $item['item_number']['options']['recurring']['signup_fee'];

			if( ! empty( $item['fees'] ) ) {
				foreach( $item['fees'] as $fee ) {
					$fees += $fee['amount'];
				}
			}

			$args = apply_filters( 'edd_recurring_subscription_pre_gateway_args', array(
				'id'               => $item['id'],
				'name'             => $item['name'],
				'price_id'         => isset( $item['item_number']['options']['price_id'] ) ? $item['item_number']['options']['price_id'] : null,
				'initial_amount'   => edd_sanitize_amount( $item['price'] + $fees ),
				'recurring_amount' => edd_sanitize_amount( $recurring_amount ),
				'tax'              => edd_sanitize_amount( $item['tax'] ),
				'period'           => $item['item_number']['options']['recurring']['period'],
				'frequency'        => 1, // Hard-coded to 1 for now but here in case we offer it later. Example: charge every 3 weeks
				'bill_times'       => $item['item_number']['options']['recurring']['times'],
				'profile_id'       => '', // Profile ID for this subscription - This is set by the payment gateway
				'transaction_id'   => '', // Transaction ID for this subscription - This is set by the payment gateway
			), $item );

			$this->subscriptions[] = $args;

		}

		do_action( 'edd_recurring_pre_create_payment_profiles', $this );


		// Create subscription payment profiles in the gateway
		$this->create_payment_profiles();

		do_action( 'edd_recurring_post_create_payment_profiles', $this );

		// Look for errors after trying to create payment profiles
		$errors = edd_get_errors();

		if ( $errors ) {

			edd_send_back_to_checkout( '?payment-mode=' . $this->id );

		}

		// Record the subscriptions and finish up
		$this->record_signup();

		// Finish the signup process. Gateways can perform off-site redirects here if necessary
		$this->complete_signup();

		// Look for any last errors
		$errors = edd_get_errors();

		// We shouldn't usually get here, but just in case a new error was recorded, we need to check for it
		if ( $errors ) {

			edd_send_back_to_checkout( '?payment-mode=' . $this->id );

		}

	}

	/**
	 * Records purchased subscriptions in the database and creates an edd_payment record
	 *
	 * @access      public
	 * @since       2.4
	 * @return      void
	 */
	public function record_signup() {

		$payment_data = array(
			'price'        => $this->purchase_data['price'],
			'date'         => $this->purchase_data['date'],
			'user_email'   => $this->purchase_data['user_email'],
			'purchase_key' => $this->purchase_data['purchase_key'],
			'currency'     => edd_get_currency(),
			'downloads'    => $this->purchase_data['downloads'],
			'user_info'    => $this->purchase_data['user_info'],
			'cart_details' => $this->purchase_data['cart_details'],
			'status'       => 'pending'
		);

		// Record the pending payment
		$this->payment_id = edd_insert_payment( $payment_data );

		if ( ! $this->offsite ) {

			// Offsite payments get verified via a webhook so are completed in webhooks()
			edd_update_payment_status( $this->payment_id, 'publish' );

		}

		// Set subscription_payment
		edd_update_payment_meta( $this->payment_id, '_edd_subscription_payment', true );

		$subscriber = new EDD_Recurring_Subscriber( $this->customer_id );

		// Now create the subscription record(s)
		foreach ( $this->subscriptions as $subscription ) {

			if( isset( $subscription['status'] ) ) {
				$status  = $subscription['status'];
			} else {
				$status  = $this->offsite ? 'pending' : 'active';
			}

			$args        = array(
				'product_id'        => $subscription['id'],
				'user_id'           => $this->purchase_data['user_info']['id'],
				'parent_payment_id' => $this->payment_id,
				'status'            => $status,
				'period'            => $subscription['period'],
				'initial_amount'    => $subscription['initial_amount'],
				'recurring_amount'  => $subscription['recurring_amount'],
				'bill_times'        => $subscription['bill_times'],
				'expiration'        => $subscriber->get_new_expiration( $subscription['id'], $subscription['price_id'] ),
				'profile_id'        => $subscription['profile_id'],
				'transaction_id'    => $subscription['transaction_id'],
			);

			$subscription = $subscriber->add_subscription( $args );

		}

	}

	/**
	 * Triggers the validate_fields() method for the gateway during checkout submission
	 *
	 * This should not be extended
	 *
	 * @access      public
	 * @since       2.4
	 * @return      void
	 */
	public function checkout_errors( $data, $posted ) {

		if ( $this->id !== $posted['edd-gateway'] ) {
			return;
		}

		if( ! edd_recurring()->cart_contains_recurring() ) {
			return;
		}

		$this->validate_fields( $data, $posted );

	}

	/**
	 * Process the update payment form
	 *
	 * @since  2.4
	 * @param  int  $user_id            User ID
	 * @param  int  $subscription_id    Subscription ID
	 * @param  bool $verified           Sanity check that the request to update is coming from a verified source
	 * @return void
	 */
	public function process_payment_method_update( $user_id, $subscription_id, $verified ) {

		if ( 1 !== $verified ) {
			wp_die( __( 'Unable to verify payment update.', 'edd-recurring' ) );
		}

		if ( ! is_user_logged_in() ) {
			wp_die( __( 'You must be logged in to update a payment method.', 'edd-recurring' ) );
		}

		$subscription = new EDD_Subscription( $subscription_id );
		if ( $subscription->gateway !== $this->id ) {
			return;
		}

		if ( empty( $subscription->id ) ) {
			wp_die( __( 'Invalid subscription id.', 'edd-recurring' ) );
		}

		$subscriber   = new EDD_Recurring_Subscriber( $subscription->customer_id );
		if ( empty( $subscriber->id ) ) {
			wp_die( __( 'Invalid subscriber.', 'edd-recurring' ) );
		}

		// Make sure the User doing the udpate is the user the subscription belongs to
		if ( $user_id != $subscriber->user_id ) {
			wp_die( __( 'User ID and Subscriber do not match.', 'edd-recurring' ) );
		}

		// make sure we don't have any left over errors present
		edd_clear_errors();

		do_action( 'edd_recurring_update_' . $subscription->gateway .'_subscription', $subscriber, $subscription );

		$errors = edd_get_errors();

		if ( empty( $errors ) ) {

			$url = add_query_arg( array( 'updated' => true ) );
			wp_redirect( $url );
			die();
		}

		$url = add_query_arg( array( 'action' => 'update', 'subscription_id' => $subscription->id ) );
		wp_redirect( $url );
		die();

	}

	/**
	 * Handles cancellation requests for a subscription
	 *
	 * This should not be extended
	 *
	 * @access      public
	 * @since       2.4
	 * @return      void
	 */
	public function process_cancellation( $data ) {


		if( empty( $data['sub_id'] ) ) {
			return;
		}

		if( ! is_user_logged_in() ) {
			return;
		}

		if( ! wp_verify_nonce( $data['_wpnonce'], 'edd-recurring-cancel' ) ) {
			wp_die( __( 'Error', 'edd-recurring' ), __( 'Nonce verification failed', 'edd-recurring' ), array( 'response' => 403 ) );
		}

		$data['sub_id'] = absint( $data['sub_id'] );
		$subscription   = new EDD_Subscription( $data['sub_id'] );

		if( ! $subscription->can_cancel() ) {
			wp_die( __( 'Error', 'edd-recurring' ), __( 'This subscription cannot be cancelled', 'edd-recurring' ), array( 'response' => 403 ) );
		}

		try {

			do_action( 'edd_recurring_cancel_' . $subscription->gateway . '_subscription', $subscription, true );

			$subscription->cancel();

			if( is_admin() ) {

				wp_redirect( admin_url( 'edit.php?post_type=download&page=edd-subscriptions&edd-message=cancelled&id=' . $subscription->id ) );
				exit;

			} else {

				wp_redirect( remove_query_arg( array( '_wpnonce', 'edd_action', 'sub_id' ), add_query_arg( array( 'edd-message' => 'cancelled' ) ) ) );
				exit;

			}

		} catch ( Exception $e ) {
			wp_die( __( 'Error', 'edd-recurring' ), $e->getMessage(), array( 'response' => 403 ) );
		}

	}

	/**
	 * Make it so that accounts are required
	 *
	 * @access      public
	 * @since       2.4
	 * @return      void
	 */
	public function require_login() {

		$cart_items    = edd_get_cart_contents();
		$has_recurring = false;

		if ( empty( $cart_items ) ) {
			return;
		}


		// Loops through each item to see if any of them are recurring
		foreach( $cart_items as $item ) {

			if( ! isset( $item['options']['recurring'] ) ) {
				continue;
			}

			$has_recurring = true;

		}

		$auto_register = class_exists( 'EDD_Auto_Register' );

		if( $has_recurring && ! $auto_register ) {

			add_filter( 'edd_no_guest_checkout', '__return_true' );
			add_filter( 'edd_logged_in_only', '__return_true' );

		}

	}

	/**
	 * Retrieve subscription details
	 *
	 * This method should be extended by each gateway in order to call the gateway API to determine the status and expiration of the subscription
	 *
	 * @access      public
	 * @since       2.4
	 * @return      array
	 */
	public function get_subscription_details( EDD_Subscription $subscription ) {

		/*
		 * Return value for valid subscriptions should be an array containing the following keys:
		 *
		 * - status: The status of the subscription (active, cancelled, expired, completed, pending, failing)
		 * - expiration: The expiration / renewal date of the subscription
		 * - error: An instance of WP_Error with error code and message (if any)
		 */

		$ret = array(
			'status'     => '',
			'expiration' => '',
			'error'      => '',
		);

		return $ret;
	}

	public function link_profile_id( $profile_id, $subscription ) {
		return $profile_id;
	}

}
